@@ -126,14 +126,6 @@ class FileAdminBase(admin.ModelAdmin):
 
         return super(FileAdminBase, self).to_field_allowed(request, to_field)
 
-    # Customizations.
-
-    def lookup_allowed(self, lookup, *args, **kwargs):
-        """Allows the file iregex lookup needed by Redactor integration."""
-        if lookup == "file__iregex":
-            return True
-        return super(FileAdminBase, self).lookup_allowed(lookup, *args, **kwargs)
-
     # Custom actions.
 
     def add_label_action(self, request, queryset, label):
@@ -157,30 +149,17 @@ class FileAdminBase(admin.ModelAdmin):
         for label in Label.objects.all():
             # Add action.
             action_function = partial(self.__class__.add_label_action, label=label)
-            action_description = u'Remove label %s from selected %s"' % (label.name, verbose_name_plural)
+            action_description = 'Remove label %s from selected %s"' % (label.name, verbose_name_plural)
             action_name = action_description.lower().replace(" ", "_")
             actions[action_name] = (action_function, action_name, action_description)
             # Remove action.
             action_function = partial(self.__class__.remove_label_action, label=label)
-            action_description = u'Remove label %s from selected %s"' % (label.name, verbose_name_plural)
+            action_description = 'Remove label %s from selected %s"' % (label.name, verbose_name_plural)
             action_name = action_description.lower().replace(" ", "_")
             actions[action_name] = (action_function, action_name, action_description)
         return actions
 
-    def remove_label(self, request, queryset):
-        """Removes the label from selected files."""
-        queryset.update(label=None)
-
     # Custom display routines.
-
-    def get_label(self, obj):
-        """Returns a pretty version of the label."""
-        if obj.label:
-            return obj.label.name
-        return ""
-    get_label.short_description = "label"
-    get_label.admin_order_field = "label"
-
     def get_size(self, obj):
         """Returns the size of the media in a human-readable format."""
         try:
@@ -201,11 +180,24 @@ class FileAdminBase(admin.ModelAdmin):
             except IOError:
                 pass
             else:
-                return '<img cms:permalink="%s" src="%s" width="%s" height="%s" alt="" title="%s"/>' % (permalink, thumbnail.url, thumbnail.width, thumbnail.height, obj.title)
+                try:
+                    return '<img cms:permalink="{}" src="{}" width="{}" height="{}" alt="" title="{}"/>'.format(
+                        permalink,
+                        thumbnail.url,
+                        thumbnail.width,
+                        thumbnail.height,
+                        obj.title
+                    )
+                except TypeError:
+                    pass
         else:
             icon = staticfiles_storage.url(icon)
 
-        return '<img cms:permalink="%s" src="%s" width="66" height="66" alt="" title="%s"/>' % (permalink, icon, obj.title)
+        return '<img cms:permalink="{}" src="{}" width="66" height="66" alt="" title="{}"/>'.format(
+            permalink,
+            icon,
+            obj.title
+        )
     get_preview.short_description = "preview"
     get_preview.allow_tags = True
 
@@ -269,8 +261,8 @@ class FileAdminBase(admin.ModelAdmin):
         obj = get_object_or_404(File, pk=object_id)
         obj.file.save(url.split('/')[-1], DjangoFile(img_temp))
 
-        messages.success(request, u'The file "{}" was changed successfully. You may edit it again below.'.format(
-            obj.__unicode__()
+        messages.success(request, 'The file "{}" was changed successfully. You may edit it again below.'.format(
+            obj.__str__()
         ))
         return HttpResponse('{"status": "ok"}', content_type='application/json')
 
@@ -353,7 +345,6 @@ class FileAdminBase(admin.ModelAdmin):
             return HttpResponse('')
 
 
-
 # Renaming needed to allow inheritance to take place in this class without infinite recursion.
 FileAdmin = FileAdminBase
 
