@@ -1,13 +1,17 @@
 """Models used by the static media management application."""
+from __future__ import unicode_literals
+
 from PIL import Image
 
 from django.db import models
 from django.contrib import admin
 from django.contrib.admin.widgets import ForeignKeyRawIdWidget
+from django.utils.encoding import python_2_unicode_compatible
 
 import os
 
 
+@python_2_unicode_compatible
 class Label(models.Model):
 
     """
@@ -18,7 +22,7 @@ class Label(models.Model):
 
     name = models.CharField(max_length=200)
 
-    def __unicode__(self):
+    def __str__(self):
         """Returns the name of the label."""
         return self.name
 
@@ -26,6 +30,7 @@ class Label(models.Model):
         ordering = ("name",)
 
 
+@python_2_unicode_compatible
 class File(models.Model):
 
     """A static file."""
@@ -48,7 +53,7 @@ class File(models.Model):
         """Generates the absolute URL of the image."""
         return self.file.url
 
-    def __unicode__(self):
+    def __str__(self):
         """Returns the title of the media."""
         return self.title
 
@@ -66,18 +71,24 @@ class File(models.Model):
     def width(self):
         if self.is_image():
             with open(self.file.path, "rb") as f:
-                image = Image.open(f)
+                try:
+                    image = Image.open(f)
+                except IOError:
+                    return 0
             image.verify()
             return image.size[0]
-        return 0;
+        return 0
 
     def height(self):
         if self.is_image():
             with open(self.file.path, "rb") as f:
-                image = Image.open(f)
+                try:
+                    image = Image.open(f)
+                except IOError:
+                    return 0
             image.verify()
             return image.size[1]
-        return 0;
+        return 0
 
 
 class FileRefField(models.ForeignKey):
@@ -85,7 +96,7 @@ class FileRefField(models.ForeignKey):
     """A foreign key to a File, constrained to only select image files."""
 
     def __init__(self, **kwargs):
-        kwargs["to"] = File
+        kwargs["to"] = 'media.File'
         kwargs.setdefault("related_name", "+")
         kwargs.setdefault("on_delete", models.PROTECT)
         super(FileRefField, self).__init__(**kwargs)
@@ -117,6 +128,7 @@ VIDEO_FILTER = {
 
 
 class VideoFileRefField(FileRefField):
+
     """A foreign key to a File, constrained to only select video files."""
 
     def __init__(self, **kwargs):
@@ -124,6 +136,7 @@ class VideoFileRefField(FileRefField):
         super(VideoFileRefField, self).__init__(**kwargs)
 
 
+@python_2_unicode_compatible
 class Video(models.Model):
 
     title = models.CharField(
@@ -153,7 +166,7 @@ class Video(models.Model):
         null=True,
     )
 
-    def __unicode__(self):
+    def __str__(self):
         """Returns the title of the media."""
         return self.title
 
