@@ -6,26 +6,33 @@ user-friendly appearance and providing additional functionality over the
 standard implementation.
 """
 
-from __future__ import with_statement
+from __future__ import unicode_literals, with_statement
 
-from django.contrib import admin
+from functools import cmp_to_key
+import json
+from copy import deepcopy
+
+from django.contrib import admin, messages
+from django.contrib.auth import get_permission_codename
 from django.contrib.staticfiles.storage import staticfiles_storage
-from django.core.exceptions import PermissionDenied
+from django.core.exceptions import PermissionDenied, ValidationError
 from django.core.urlresolvers import reverse
 from django.conf.urls import patterns, url
 from django.contrib.admin.widgets import FilteredSelectMultiple
 from django.contrib.contenttypes.models import ContentType
 from django.db import transaction, models
-from django.db.models import F
+from django.db.models import F, Q
 from django.http import Http404, HttpResponseRedirect, HttpResponse, HttpResponseForbidden
 from django.shortcuts import render, redirect, get_object_or_404
+from django.template.response import TemplateResponse
+from django.utils import six
 from django import forms
 
 from cms import debug, externals
 from cms.admin import PageBaseAdmin
-from cms.apps.pages.models import Page, get_registered_content, PageSearchAdapter
+from cms.apps.pages.models import Page, get_registered_content, PageSearchAdapter, Country, CountryGroup
+
 
-import json
 
 # Used to track references to and from the JS sitemap.
 PAGE_FROM_KEY = "from"
@@ -38,11 +45,13 @@ PAGE_TYPE_PARAMETER = "type"
 
 class PageAdmin(PageBaseAdmin):
 
+    list_display = ("__str__", "is_online",)
+
     """Admin settings for Page models."""
 
     fieldsets = (
         (None, {
-            "fields": ("title", "url_title", "parent",),
+            "fields": ("title", "url_title", "parent"),
         },),
         ("Publication", {
             "fields": ("publication_date", "expiry_date", "is_online",),
@@ -57,6 +66,22 @@ class PageAdmin(PageBaseAdmin):
 
     search_adapter_cls = PageSearchAdapter
 
+    change_form_template = 'admin/pages/page/change_form.html'
+
+    def get_queryset(self, request):
+        return super(PageAdmin, self).get_queryset(request).filter(is_content_object=False)
+
+    def get_object(self, request, object_id, from_field=None):
+        queryset = super(PageAdmin, self).get_queryset(request)
+        model = queryset.model
+        field = model._meta.pk if from_field is None else model._meta.get_field(
+            from_field)
+        try:
+            object_id = field.to_python(object_id)
+            return queryset.get(**{field.name: object_id})
+        except (model.DoesNotExist, ValidationError, ValueError):
+            return None
+
     def _register_page_inline(self, model):
         """Registeres the given page inline with reversion."""
         if externals.reversion:
@@ -196,10 +221,22 @@ class PageAdmin(PageBaseAdmin):
                 )
             # Store the field.
             form_attrs[field.name] = form_field
-        ContentForm = type("%sForm" % self.__class__.__name__, (forms.ModelForm,), form_attrs)
+        if six.PY2:
+            ContentForm = type(six.binary_type("{}Form").format(self.__class__.__name__), (forms.ModelForm,), form_attrs)
+        else:
+            ContentForm = type(six.text_type("{}Form".format(self.__class__.__name__)), (forms.ModelForm,), form_attrs)
         defaults = {"form": ContentForm}
         defaults.update(kwargs)
+
+        if obj and obj.is_content_object == True:
+            self.prepopulated_fields = {}
+            self.fieldsets[0][1]['fields'] = ('title',)
+        else:
+            self.prepopulated_fields = {"url_title": ("title",), }
+            self.fieldsets[0][1]['fields'] = ("title", "url_title", "parent")
+
         PageForm = super(PageAdmin, self).get_form(request, obj, **defaults)
+
         # HACK: Need to limit parents field based on object. This should be done in
         # formfield_for_foreignkey, but that method does not know about the object instance.
         if obj:
@@ -208,16 +245,23 @@ class PageAdmin(PageBaseAdmin):
         else:
             invalid_parents = frozenset()
         homepage = request.pages.homepage
+
         if homepage:
             parent_choices = []
             for page in [homepage] + self.get_all_children(homepage):
-                if not page.id in invalid_parents:
-                    parent_choices.append((page.id, u" \u203a ".join(unicode(breadcrumb) for breadcrumb in self.get_breadcrumbs(page))))
+                if page.id not in invalid_parents:
+                    parent_choices.append((page.id, " \u203a ".join(str(breadcrumb) for breadcrumb in self.get_breadcrumbs(page))))
         else:
             parent_choices = []
+
         if not parent_choices:
             parent_choices = (("", "---------"),)
-        PageForm.base_fields["parent"].choices = parent_choices
+
+        if obj and not obj.is_content_object:
+            PageForm.base_fields["parent"].choices = parent_choices
+        elif not obj:
+            PageForm.base_fields["parent"].choices = parent_choices
+
         # Return the completed form.
         return PageForm
 
@@ -259,7 +303,7 @@ class PageAdmin(PageBaseAdmin):
     def has_add_content_permission(self, request, model):
         """Checks whether the given user can edit the given content model."""
         opts = model._meta
-        return request.user.has_perm("{0}.{1}".format(opts.app_label, opts.get_add_permission()))
+        return request.user.has_perm("{0}.{1}".format(opts.app_label, get_permission_codename('add', opts)))
 
     def has_add_permission(self, request):
         """Checks whether the user can edits pages and at least one content model."""
@@ -279,7 +323,7 @@ class PageAdmin(PageBaseAdmin):
             content_opts = content_model._meta
             return request.user.has_perm("{0}.{1}".format(
                 content_opts.app_label,
-                content_opts.get_change_permission(),
+                get_permission_codename('change', content_opts)
             ))
         return True
 
@@ -292,7 +336,7 @@ class PageAdmin(PageBaseAdmin):
             content_opts = content_model._meta
             return request.user.has_perm("{0}.{1}".format(
                 content_opts.app_label,
-                content_opts.get_delete_permission(),
+                get_permission_codename('delete', content_opts)
             ))
         return True
 
@@ -318,8 +362,23 @@ class PageAdmin(PageBaseAdmin):
         # HACK: Add the current page to the request to pass to the get_inline_instances() method.
         page = get_object_or_404(self.model, id=object_id)
         request._admin_change_obj = page
+
+        extra_context = {}
+
+        if not page.is_content_object:
+            # Get all of the language pages
+            extra_context['language_pages'] = Page.objects.filter(
+                Q(pk=page.pk) |
+                Q(owner=page, is_content_object=True)
+            ).order_by('-country_group')
+        else:
+            extra_context['language_pages'] = Page.objects.filter(
+                Q(pk=page.owner.pk) |
+                Q(owner=page.owner, is_content_object=True)
+            ).order_by('-country_group')
+
         # Call the change view.
-        return super(PageAdmin, self).change_view(request, object_id, *args, **kwargs)
+        return super(PageAdmin, self).change_view(request, object_id, extra_context=extra_context, *args, **kwargs)
 
     def revision_view(self, request, object_id, *args, **kwargs):
         """Load up the correct content inlines."""
@@ -331,10 +390,15 @@ class PageAdmin(PageBaseAdmin):
 
     def add_view(self, request, *args, **kwargs):
         """Ensures that a valid content type is chosen."""
-        if not PAGE_TYPE_PARAMETER in request.GET:
+        if PAGE_TYPE_PARAMETER not in request.GET:
             # Generate the available content items.
             content_items = get_registered_content()
-            content_items.sort(lambda a, b: cmp(a.classifier, b.classifier) or cmp(a._meta.verbose_name.lower(), b._meta.verbose_name.lower()))
+
+            def cmp_function(a, b):
+                return (a.classifier > b.classifier) - (a.classifier < b.classifier) or \
+                       (a._meta.verbose_name.lower() > b._meta.verbose_name.lower()) - (a._meta.verbose_name.lower() < b._meta.verbose_name.lower())
+
+            content_items.sort(key=cmp_to_key(cmp_function))
             content_types = []
             for content_type in content_items:
                 if self.has_add_content_permission(request, content_type):
@@ -387,6 +451,7 @@ class PageAdmin(PageBaseAdmin):
             "",
             url("^sitemap.json$", admin_view(self.sitemap_json_view), name="pages_page_sitemap_json"),
             url("^move-page/$", admin_view(self.move_page_view), name="pages_page_move_page"),
+            url("^(?P<page>\d+)/duplicate/$", admin_view(self.duplicate_for_country_group), name="pages_page_duplicate_page"),
         ) + super(PageAdmin, self).get_urls()
 
     @debug.print_exc
@@ -412,7 +477,7 @@ class PageAdmin(PageBaseAdmin):
                 return {
                     "isOnline": page.is_online,
                     "id": page.id,
-                    "title": unicode(page),
+                    "title": str(page),
                     "children": children,
                     "canChange": self.has_change_permission(request, page),
                     "canDelete": self.has_delete_permission(request, page),
@@ -464,25 +529,66 @@ class PageAdmin(PageBaseAdmin):
         first_page, second_page = sorted((page, other_page), key=lambda p: p["left"])
         # Excise the first page.
         Page.objects.filter(left__gte=first_page["left"], right__lte=first_page["right"]).update(
-            left = F("left") * -1,
-            right = F("right") * -1,
+            left=F("left") * -1,
+            right=F("right") * -1,
         )
         # Move the other page.
         branch_width = first_page["right"] - first_page["left"] + 1
         Page.objects.filter(left__gte=second_page["left"], right__lte=second_page["right"]).update(
-            left = F("left") - branch_width,
-            right = F("right") - branch_width,
+            left=F("left") - branch_width,
+            right=F("right") - branch_width,
         )
         # Put the page back in.
         second_branch_width = second_page["right"] - second_page["left"] + 1
         Page.objects.filter(left__lte=-first_page["left"], right__gte=-first_page["right"]).update(
-            left = (F("left") - second_branch_width) * -1,
+            left=(F("left") - second_branch_width) * -1,
             right = (F("right") - second_branch_width) * -1,
         )
         # Report back.
         return HttpResponse("Page #%s was moved %s." % (page["id"], direction))
 
+    def duplicate_for_country_group(self, request, *args, **kwargs):
+        # Get the current page
+        original_page = get_object_or_404(Page, pk=kwargs.get('page', None))
+        original_content = original_page.content
+
+        if request.method == 'POST':
+
+            with externals.watson.context_manager("update_index")():
+                page = deepcopy(original_page)
+                page.pk = None
+                page.is_content_object = True
+                page.owner = original_page
+                page.country_group = CountryGroup.objects.get(pk=request.POST.get('country_group'))
+                page.save()
+
+                content = deepcopy(original_content)
+                content.pk = None
+                content.page = page
+                content.save()
+
+            return redirect('/admin/pages/page/{}'.format(page.pk))
+
+        country_groups = CountryGroup.objects.all()
+
+        if not country_groups:
+            messages.add_message(request, messages.ERROR, 'You need to add at least one country group first before you can add a copy of this page')
+            return redirect('/admin/pages/page/{}'.format(original_page.pk))
+
+        context = dict(
+            original_page=original_page,
+            country_groups=country_groups
+        )
+
+        return TemplateResponse(request, 'admin/pages/page/language_duplicate.html', context)
+
+
+class CountryGroupAdmin(admin.ModelAdmin):
+    pass
+
 
 admin.site.register(Page, PageAdmin)
+admin.site.register(Country)
+admin.site.register(CountryGroup, CountryGroupAdmin)
 
 page_admin = admin.site._registry[Page]
