@@ -4,15 +4,16 @@ import traceback
 from functools import wraps
 
 from django.conf import settings
+from django.utils import six
 
 
 def print_exc(func):
     """
     Decorator that prints any raised exceptions to stdout, but only when in debug mode.
-    
+
     This is useful for catching those pesky errors that Django would otherwise squeltch.
     """
-    if settings.DEBUG:
+    if settings.DEBUG and six.PY2:
         @wraps(func)
         def wrapper(*args, **kwargs):
             try:
@@ -23,9 +24,9 @@ def print_exc(func):
         return wrapper
     else:
         return func
-        
-        
+
+
 def print_current_exc():
     """Prints the current exception, if in debug model"""
-    if settings.DEBUG:
-        traceback.print_exc()
\ No newline at end of file
+    if settings.DEBUG and six.PY2:
+        traceback.print_exc()
