@@ -1,7 +1,3 @@
-"""Form widgets used by the CMS."""
-import re
-import string
-
 from django import forms
 from django.conf import settings
 from django.contrib.auth.forms import PasswordChangeForm, AdminPasswordChangeForm
@@ -11,13 +7,13 @@ from django.utils.safestring import mark_safe
 
 from cms import debug
 
-try:
-    import json
-except:
-    from django.utils import simplejson as json
+import json
+import re
+import string
 
 
 class HtmlWidget(forms.Textarea):
+
     """A textarea that is converted into a Redactor editor."""
 
     def __init__(self, *args, **kwargs):
@@ -28,14 +24,14 @@ class HtmlWidget(forms.Textarea):
     def get_media(self):
         """Returns the media used by the widget."""
         js = [
-                 staticfiles_storage.url("cms/js/jquery.cms.js"),
-                 staticfiles_storage.url("cms/js/jquery.cookie.js"),
-                 staticfiles_storage.url("pages/js/jquery.cms.pages.js"),
-                 staticfiles_storage.url("cms/js/redactor/redactor.js"),
-             ] + [
-                 staticfiles_storage.url('cms/js/redactor/plugins/{plugin}/{plugin}.js'.format(plugin=plugin))
-                 for plugin in getattr(settings, 'REDACTOR_OPTIONS', {}).get('plugins', [])
-             ]
+            staticfiles_storage.url("cms/js/jquery.cms.js"),
+            staticfiles_storage.url("cms/js/jquery.cookie.js"),
+            staticfiles_storage.url("pages/js/jquery.cms.pages.js"),
+            staticfiles_storage.url("cms/js/redactor/redactor.js"),
+        ] + [
+            staticfiles_storage.url('cms/js/redactor/plugins/{plugin}/{plugin}.js'.format(plugin=plugin))
+            for plugin in getattr(settings, 'REDACTOR_OPTIONS', {}).get('plugins', [])
+        ]
 
         css = {
             "all": [
@@ -65,7 +61,7 @@ class HtmlWidget(forms.Textarea):
             pass
         else:
             # Add in the initializer.
-            html += u'<script>django.jQuery("#{element_id}").redactor({settings_js});</script>'.format(
+            html += '<script>django.jQuery("#{element_id}").redactor({settings_js});</script>'.format(
                 element_id=element_id,
                 settings_js=json.dumps(getattr(settings, 'REDACTOR_OPTIONS', {})),
             )
@@ -96,6 +92,7 @@ def password_validation(password):
 
 
 class CMSPasswordChangeForm(PasswordChangeForm):
+
     def clean_new_password1(self):
         password = self.cleaned_data.get('new_password1')
         if password_validation(password):
@@ -106,6 +103,7 @@ class CMSPasswordChangeForm(PasswordChangeForm):
 
 
 class CMSAdminPasswordChangeForm(AdminPasswordChangeForm):
+
     def clean_password1(self):
         password = self.cleaned_data.get('password1')
         if password_validation(password):
