@@ -29,8 +29,8 @@ var config = {
     },
     js: {
         src: [
-            templateFolder + '*.js',
-            templateFolder + '/**/*.js'
+            staticFolder + '*.js',
+            staticFolder + '/**/*.js'
         ]
     },
     html: {
@@ -156,7 +156,7 @@ gulp.task('default', function(callback) {
         'styles',
 
         // Start watching for changes to SCSS files.
-        'watch',
+        'serve',
 
         callback
     );
