@@ -8,10 +8,12 @@ For an explanation of these settings, please see the Django documentation at:
 While many of these settings assume sensible defaults, you must provide values
 for the site, database, media and email sections below.
 """
+from __future__ import unicode_literals
 
 from social.pipeline import DEFAULT_AUTH_PIPELINE
 
 import os
+import sys
 
 
 # The name of this site.  Used for branding in the online admin area.
@@ -73,7 +75,7 @@ EMAIL_PORT = 587
 
 EMAIL_USE_TLS = True
 
-SERVER_EMAIL = u"{name} <notifications@{domain}>".format(
+SERVER_EMAIL = "{name} <notifications@{domain}>".format(
     name=SITE_NAME,
     domain=SITE_DOMAIN,
 )
@@ -132,7 +134,7 @@ INSTALLED_APPS = (
 
     "reversion",
     "usertools",
-    "historylinks",
+    # "historylinks",
     "watson",
 
     "cms.apps.pages",
@@ -173,7 +175,6 @@ COMPRESS_CSS_FILTERS = [
 # Dispatch settings.
 
 MIDDLEWARE_CLASSES = (
-    "django.middleware.transaction.TransactionMiddleware",
     "django.middleware.common.CommonMiddleware",
     "django.contrib.sessions.middleware.SessionMiddleware",
     "django.middleware.csrf.CsrfViewMiddleware",
@@ -181,7 +182,7 @@ MIDDLEWARE_CLASSES = (
     "django.contrib.messages.middleware.MessageMiddleware",
     "django.middleware.clickjacking.XFrameOptionsMiddleware",
     "watson.middleware.SearchContextMiddleware",
-    "historylinks.middleware.HistoryLinkFallbackMiddleware",
+    # "historylinks.middleware.HistoryLinkFallbackMiddleware",
     "cms.middleware.PublicationMiddleware",
     "cms.apps.pages.middleware.PageMiddleware",
 )
@@ -304,8 +305,32 @@ AUTHENTICATION_BACKENDS = (
 SOCIAL_AUTH_GOOGLE_PLUS_KEY = ''
 SOCIAL_AUTH_GOOGLE_PLUS_SECRET = ''
 WHITELISTED_DOMAINS = ['onespacemedia.com']
+SOCIAL_AUTH_PROTECTED_USER_FIELDS = ['first_name', 'last_name']
 
 SOCIAL_AUTH_LOGIN_REDIRECT_URL = '/admin/'
 SOCIAL_AUTH_PIPELINE = DEFAULT_AUTH_PIPELINE + (
     'cms.pipeline.make_staff',
 )
+
+SILENCED_SYSTEM_CHECKS = [
+    '1_6.W001',
+    # '1_6.W002'
+]
+
+if 'test' in sys.argv:
+    # The CMS tests use test-only models, which won't be loaded if we only load
+    # our real migration files, so point to a nonexistent one, which will make
+    # the test runner fall back to 'syncdb' behavior.
+
+    # Note: This will not catch a situation where a developer commits model
+    # changes without the migration files.
+
+    class DisableMigrations(object):
+
+        def __contains__(self, item):
+            return True
+
+        def __getitem__(self, item):
+            return "notmigrations"
+
+    MIGRATION_MODULES = DisableMigrations()
