@@ -15,7 +15,7 @@ register = template.Library()
 def html(text):
     """
     Processes HTML text.
-    
+
     The text is checked for permalinks embedded in <a> tags, expanding the
     permalinks to their referenced URL. Images containing a permalink source
     are checked for size and thumbnailed as appropriate.
@@ -33,10 +33,10 @@ def truncate_paragraphs(text, number):
     position = 0
     count = 0
     while count < number and position < len(text):
-        position = text.find(u"</p>", position)
+        position = text.find("</p>", position)
         if position == -1:
             position = len(text)
         else:
             position += 4
         count += 1
-    return text[:position]
\ No newline at end of file
+    return text[:position]
